<?php

/**
 * Checks if the value of the Facebook field is URL or username.
 *
 * @param <type> $string
 * @return boolean
 */
function padd_theme_check_facebook_url($string) {
	$url = false;
	if ('http://' == substr($string, 0, 7)) {
		$url = true;
	}
	return $url;
}

/**
 * Trim the title.
 *
 * @param int $length Number of letters.
 * @param string $after Ellipsis by default.
 */
function padd_theme_trim_title($length, $after='...') {
	$title = get_the_title();
	if (strlen($title) > $length ) {
		$title = substr($title, 0, $length);
		echo $title . $after;
	} else {
		echo $title;
	}
}

/**
 * Renders the list of social networking websites.
 */
function padd_theme_widget_socialnet() {
	global $_PADD_SOCIALNET;
?>
	<ul class="socialnet">
	<?php foreach ($_PADD_SOCIALNET as $k => $v) : ?>
		<?php
			$url = '';
			$v->username = Padd_Theme_Option::get('sn_username_' . $k);
			if ('facebook' == $k) {
				$fburl = Padd_Theme_Option::get('sn_username_facebook');
				if (!padd_theme_check_facebook_url($fburl) && !empty($fburl)) {
					$v->username = $fburl;
					$url = (string) $v;
				} else if (!empty($fburl)) {
					$url = $fburl;
				}
			} else if ('rss' == $k) {
				if (empty($v->username)) {
					$url = get_bloginfo('rss2_url');
				} else {
					$url = (string) $v;
				}
			} else {
				continue;
			}
		?>
		<?php if (!empty($v->short_desc)) : ?>
		<li class="<?php echo $k; ?>">
			<a href="<?php echo $url; ?>" class="icon-<?php echo $k; ?>" title="<?php echo $v->network; ?>"><?php echo $v->short_desc; ?></a>
		</li>
		<?php endif; ?>
	<?php endforeach; ?>
	</ul>
<?php
}

/**
 * Renders the twitter widget.
 */
function padd_theme_widget_twitter() {
	global $_PADD_SOCIALNET;
	$_PADD_SOCIALNET['twitter']->username = (Padd_Theme_Option::get('sn_username_twitter'));
	$padd_sb_twitter = Padd_Theme_Option::get('sn_username_twitter');
	$twitter = new Padd_Theme_Twitter($padd_sb_twitter, 5, true);
	$twitter->show_tweets();
	?>
	<!-- <p class="follow"><?php echo sprintf(__('Follow %s', PADD_THEME_SLUG), '<a href="' . $_PADD_SOCIALNET['twitter'] . '">@' . $padd_sb_twitter . '</a>'); ?></p> -->
	<?php
}

/**
 * Renders the banner advertisement
 */
function padd_theme_widget_banner() {
	$ad = Padd_Theme_Option::get('ads_728090_1');
	echo stripslashes($ad);
}

/**
 * Renders the advertisements.
 */
function padd_theme_widget_sponsors() {
	echo '<div class="ads-area clear-fix">';
	$ad = Padd_Theme_Option::get('ads_300250_1');
	echo stripslashes($ad);
	echo '</div>';
}

/**
 * Renders the Facebook Like Box.
 *
 * @paran string $id Facebook numerical ID
 * @param int $w Width of the box
 * @param int $h Height of the box
 * @param int $conn Number of connections
 * @param int $stream News feed streaming. 1 to enable, 0 to disable. The default value is 0.
 * @param int $header Like Box header. 1 to show, 0 to hide. The default value is 0.
 */
function padd_theme_widget_facebook_likebox($w=280,$h=300,$conn=10,$stream=0,$header=0) {
	global $padd_socialnet;
	$fburl = Padd_Theme_Option::get('sn_username_facebook');
	if (!padd_theme_check_facebook_url($fburl)) {
		$padd_socialnet['facebook']->username = $fburl;
		$fburl = (string) $padd_socialnet['facebook'];
	}
?>
<iframe src="http://www.facebook.com/plugins/likebox.php?href=<?php echo urlencode($fburl); ?>&amp;width=<?php echo $w; ?>&amp;connections=<?php echo $conn; ?>&amp;stream=<?php echo $stream == 1 ? 'true' : 'false'; ?>&amp;header=<?php echo $header == 1 ? 'true' : 'false'; ?>&amp;height=<?php echo $h; ?>" scrolling="no" frameborder="0" style="border:none; overflow:hidden; width:<?php echo $w; ?>px; height:<?php echo $h; ?>px;"></iframe>
<?php
}

function padd_theme_widget_flickrrss_ru() {
?>
<div class="interior clear-fix">
<?php
	if (function_exists('get_flickrRSSRU')) {
		get_flickrRSSRU();
	} else {
		echo '<p>', sprintf(__('You have to install the <a href="%s">FlickrRSS RU</a> plugin first.', PADD_THEME_SLUG),'http://wordpress.org/extend/plugins/flickrrss-ru/') , '</p>';
	}
?>
</div>
<?php
}

/**
 * Renders the featured video in home page.
 */
function padd_theme_widget_featured_video() {
	wp_reset_query();
	$featured = Padd_Theme_Option::get('video_cat_id');
	$count = '1';
	query_posts('showposts=' . $count . '&cat=' . $featured  .'&orderby=ID&order=DESC');
?>
<?php while (have_posts()) : the_post(); ?>
	<?php
		$customfields = get_post_custom();
		$url = $customfields['_' . PADD_NS . '_video_url'][0];
		$video = padd_theme_embed_video_clip($url, PADD_SB_VIDEO_W, PADD_SB_VIDEO_H);
		echo $video;
	?>
<?php endwhile; ?>
<?php
	wp_reset_query();
}

function padd_theme_embed_video_clip($url, $w=600, $h=340) {
	$html = wp_oembed_get($url);

	$patterns = array();
	$replacements = array();

	if (!empty($w)) {
		$patterns[] = '/width="([0-9]+)"/';
		$patterns[] = '/width:([0-9]+)/';
		$replacements[] = 'width="' . $w . '"';
		$replacements[] = 'width:' . $w;
	}
	if (!empty($h)) {
		$patterns[] = '/height="([0-9]+)"/';
		$patterns[] = '/height:([0-9]+)/';
		$replacements[] = 'height="' . $h . '"';
		$replacements[] = 'height:' . $h;
	}

	$html = preg_replace($patterns, $replacements, $html);

	return $html;
}

/**
 * Renders the recent posts, optionally with dates.
 *
 * @global WP_DB $wpdb
 * @global string $wp_locale
 * @param array|string $args
 * @return string
 */
function padd_theme_widget_recent_posts($args = '') {
	global $wpdb, $wp_locale;

	$defaults = array(
		'limit' => '3',
		'format' => 'html', 'before' => '',
		'after' => '', 'show_post_count' => false,
		'echo' => 1, 'show_date' => true, 'date_format' => 'F j, Y'
	);

	$r = wp_parse_args($args,$defaults);
	extract($r, EXTR_SKIP);

	if ('' == $type) {
		$type = 'monthly';
	}

	if ('' != $limit) {
		$limit = absint($limit);
		$limit = ' LIMIT ' . $limit;
	}

	$where = apply_filters('getarchives_where',"WHERE post_type = 'post' AND post_status = 'publish'",$r);
	$join = apply_filters('getarchives_join',"", $r);

	$output = '';

	$orderby = "post_date DESC ";
	$query = "SELECT * FROM $wpdb->posts $join $where ORDER BY $orderby $limit";
	$key = md5($query);
	$cache = wp_cache_get('padd_recent_posts','general');
	if (!isset($cache[ $key ])) {
		$arcresults = $wpdb->get_results($query);
		$cache[$key] = $arcresults;
		wp_cache_set('padd_recent_posts',$cache,'general');
	} else {
		$arcresults = $cache[$key];
	}
	if ($arcresults) {
		add_filter('excerpt_length', 'padd_theme_hook_excerpt_recent_posts_length');
		foreach ((array) $arcresults as $arcresult) {
			if ($arcresult->post_date != '0000-00-00 00:00:00' ) {
				$url = get_permalink($arcresult);
				$arc_title = $arcresult->post_title;
				if ($arc_title) {
					$text = strip_tags(apply_filters('the_title', $arc_title));
				} else {
					$text = $arcresult->ID;
				}
				$img = trim(get_the_post_thumbnail($arcresult->ID, PADD_THEME_SLUG . '-thumbnail-recent-posts'));
				$def = get_template_directory_uri() . '/images/thumbnail-recent-posts.png';
				if (empty($img)) {
					$img = '<img src="' . $def . '" title="Thumbnail" alt="Thumbnail" />';
				}
				$output .= '<li>';
				$output .= '<a href="' . get_permalink($arcresult->ID) . '" title="Permalink to ' . $text . '" class="thumbnail">' . $img . '</a>';
				$output .= '<a href="' . get_permalink($arcresult->ID) . '" title="Permalink to ' . $text . '" class="post-title">' . $text . '</a> ';
				$output .= '<span class="content">';
				$output .= get_the_excerpt();
				$output .= '</span>';
				$output .= '<span class="read-more"><a href="' . get_permalink($arcresult->ID) . '" title="Permalink to ' . $text . '" class="read-more">' . __('Read More', PADD_THEME_SLUG) . '</a></span>';
				$output .= '<div class="clear"></div>';
				$output .= '</li>';
			}
		}
		remove_filter('excerpt_length', 'padd_theme_hook_excerpt_recent_posts_length');
	}

	if ($echo) {
		echo $output;
	} else {
		return $output;
	}
}

/**
 * Renders the list of comments.
 *
 * @param string $comment
 * @param string $args
 * @param string $depth
 */
function padd_theme_single_comments($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment; ?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">
		<div class="comment-box">
			<div class="comment-interior append-clear">
				<div class="comment-author append-clear">
					<div class="comment-avatar"><?php echo get_avatar($comment,'33'); ?></div>
					<div class="comment-meta">
						<span class="author"><?php echo sprintf(__('%s says:', PADD_THEME_SLUG), get_comment_author_link()); ?></span>
						<span class="time"><?php echo get_comment_date(Padd_Theme_Option::get('date_format')); ?></span>
					</div>
				</div>
				<div class="comment-details">
					<div class="comment-details-interior">
						<?php comment_text(); ?>
						<?php if ($comment->comment_approved == '0') : ?>
						<p class="comment-notice"><?php _e('My comment is awaiting moderation.', PADD_THEME_SLUG) ?></p>
						<?php endif; ?>
					</div>
				</div>
				<div class="comment-actions clear">
					<?php edit_comment_link(__('Edit', PADD_THEME_SLUG),'<span class="edit">','</span> | ') ?>
					<?php comment_reply_link(array('respond_id' => 'reply', 'add_below' => 'comment' , 'depth' => $depth, 'max_depth' => $args['max_depth'])) ; ?>
				</div>
			</div>
		</div>
	<?php
}

/**
 * Render the list of trackbacks.
 *
 * @param string $comment
 * @param string $args
 * @param string $depth
 */
function padd_theme_single_trackbacks($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment; ?>
	<li <?php comment_class(); ?> id="pings-<?php comment_ID() ?>">
		<?php comment_author_link(); ?>
	<?php
}

/**
 * Renders the featured posts in home page.
 */
function padd_theme_post_slideshow($exclude=array()) {
	wp_reset_query();
	$featured = Padd_Theme_Option::get('slideshow_cat_id');
	$count = Padd_Theme_Option::get('slideshow_cat_limit');
	query_posts('showposts=' . $count . '&cat=' . $featured);
	$padd_image_def = get_template_directory_uri() . '/images/thumbnail-slideshow.jpg';
	add_filter('the_excerpt', 'padd_theme_hook_excerpt_slideshow');
	add_filter('excerpt_length', 'padd_theme_hook_excerpt_slideshow_length');
?>
<div id="slideshow-box">
	<div class="list">
	<?php while (have_posts()) : the_post(); ?>
		<div class="item">
			<div class="image clear-fix">
				<a href="<?php the_permalink(); ?>" title="Permanent Link to <?php the_title_attribute(); ?>">
				<?php
					$exclude[] = get_the_ID();
					if (has_post_thumbnail()) {
						the_post_thumbnail(PADD_THEME_SLUG . '-slideshow', array('title' => get_the_excerpt()));
					} else {
						echo '<img class="thumbnail" src="' . $padd_image_def . '" />';
					}
				?>
				</a>
			</div>
			<div class="meta clear-fix">
				<h3><a href="<?php the_permalink(); ?>" title="Permanent Link to <?php the_title_attribute(); ?>"><?php the_title(); ?></a></h3>
				<?php the_excerpt(); ?>
			</div>
		</div>
	<?php endwhile; ?>
	</div>
</div>
<?php
	wp_reset_query();
	remove_filter('the_excerpt', 'padd_theme_hook_excerpt_slideshow');
	remove_filter('excerpt_length','padd_theme_hook_excerpt_slideshow_length');
	return $exclude;
}

/*
Plugin Name: Nice Search
Version: 0.3
Plugin URI: http://txfx.net/wordpress-plugins/nice-search/
Description: Redirects ?s=query searches to /search/query, and converts %20 to +
Author: Mark Jaquith
Author URI: http://coveredwebservices.com/
*/
if (!function_exists('cws_nice_search_redirect')) :
	function cws_nice_search_redirect() {
		if (is_search() && strpos($_SERVER['REQUEST_URI'], '/wp-admin/') === false && strpos( $_SERVER['REQUEST_URI'], '/search/' ) === false) {
			wp_redirect(home_url('/search/' . str_replace(array(' ', '%20'),  array('+', '+'), get_query_var('s'))));
			exit();
		}
	}
	add_action( 'template_redirect', 'cws_nice_search_redirect' );
endif;